@@ -19,6 +19,7 @@ from botocore.client import BaseClient, ClientMeta
 
 from .literals import ComponentTypeType, OwnershipType, PipelineStatusType, PlatformType
 from .type_defs import (
+    AdditionalInstanceConfigurationTypeDef,
     CancelImageCreationResponseTypeDef,
     ComponentConfigurationTypeDef,
     CreateComponentResponseTypeDef,
@@ -117,7 +118,7 @@ class Exceptions:
 
 class imagebuilderClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html)
     """
 
@@ -133,7 +134,7 @@ class imagebuilderClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#can_paginate)
         """
 
@@ -143,7 +144,7 @@ class imagebuilderClient(BaseClient):
         """
         CancelImageCreation cancels the creation of Image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.cancel_image_creation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.cancel_image_creation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#cancel_image_creation)
         """
 
@@ -166,7 +167,7 @@ class imagebuilderClient(BaseClient):
         Creates a new component that can be used to build, validate, test, and assess
         your image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.create_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.create_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_component)
         """
 
@@ -193,7 +194,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.create_container_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.create_container_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_container_recipe)
         """
 
@@ -209,7 +210,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.create_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.create_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_distribution_configuration)
         """
 
@@ -228,7 +229,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.create_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.create_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_image)
         """
 
@@ -251,7 +252,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.create_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.create_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_image_pipeline)
         """
 
@@ -266,12 +267,13 @@ class imagebuilderClient(BaseClient):
         description: str = None,
         blockDeviceMappings: List["InstanceBlockDeviceMappingTypeDef"] = None,
         tags: Dict[str, str] = None,
-        workingDirectory: str = None
+        workingDirectory: str = None,
+        additionalInstanceConfiguration: "AdditionalInstanceConfigurationTypeDef" = None
     ) -> CreateImageRecipeResponseTypeDef:
         """
         Creates a new image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.create_image_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.create_image_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_image_recipe)
         """
 
@@ -295,7 +297,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.create_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.create_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_infrastructure_configuration)
         """
 
@@ -303,7 +305,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes a component build version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.delete_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.delete_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_component)
         """
 
@@ -313,7 +315,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes a container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.delete_container_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.delete_container_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_container_recipe)
         """
 
@@ -323,7 +325,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes a distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.delete_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.delete_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_distribution_configuration)
         """
 
@@ -331,7 +333,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.delete_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.delete_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_image)
         """
 
@@ -339,7 +341,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes an image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_image_pipeline)
         """
 
@@ -347,7 +349,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes an image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_image_recipe)
         """
 
@@ -357,7 +359,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes an infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.delete_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.delete_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_infrastructure_configuration)
         """
 
@@ -371,7 +373,7 @@ class imagebuilderClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#generate_presigned_url)
         """
 
@@ -379,7 +381,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets a component object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_component)
         """
 
@@ -387,7 +389,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets a component policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_component_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_component_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_component_policy)
         """
 
@@ -395,7 +397,7 @@ class imagebuilderClient(BaseClient):
         """
         Retrieves a container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_container_recipe)
         """
 
@@ -405,7 +407,7 @@ class imagebuilderClient(BaseClient):
         """
         Retrieves the policy for a container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_container_recipe_policy)
         """
 
@@ -415,7 +417,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets a distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_distribution_configuration)
         """
 
@@ -423,7 +425,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image)
         """
 
@@ -431,7 +433,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_pipeline)
         """
 
@@ -439,7 +441,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_image_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_image_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_policy)
         """
 
@@ -447,7 +449,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_recipe)
         """
 
@@ -457,7 +459,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image recipe policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_recipe_policy)
         """
 
@@ -467,7 +469,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.get_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.get_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_infrastructure_configuration)
         """
 
@@ -490,7 +492,7 @@ class imagebuilderClient(BaseClient):
         """
         Imports a component and transforms its data into a component document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.import_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.import_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#import_component)
         """
 
@@ -500,7 +502,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns the list of component build versions for the specified semantic version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_component_build_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_component_build_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_component_build_versions)
         """
 
@@ -516,7 +518,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns the list of component build versions for the specified semantic version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_components)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_components)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_components)
         """
 
@@ -531,7 +533,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of container recipes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_container_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_container_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_container_recipes)
         """
 
@@ -545,7 +547,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of distribution configurations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_distribution_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_distribution_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_distribution_configurations)
         """
 
@@ -560,7 +562,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of image build versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_image_build_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_image_build_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_build_versions)
         """
 
@@ -569,9 +571,9 @@ class imagebuilderClient(BaseClient):
     ) -> ListImagePackagesResponseTypeDef:
         """
         List the Packages that are associated with an Image Build Version, as determined
-        by AWS Systems Manager Inventory at build time.
+        by Amazon EC2 Systems Manager Inventory at build time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_image_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_image_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_packages)
         """
 
@@ -586,7 +588,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of images created by the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipeline_images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipeline_images)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_pipeline_images)
         """
 
@@ -600,7 +602,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of image pipelines.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_pipelines)
         """
 
@@ -615,7 +617,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of image recipes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_image_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_image_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_recipes)
         """
 
@@ -632,7 +634,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns the list of images that you have access to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_images)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_images)
         """
 
@@ -646,7 +648,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of infrastructure configurations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_infrastructure_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_infrastructure_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_infrastructure_configurations)
         """
 
@@ -654,7 +656,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns the list of tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_tags_for_resource)
         """
 
@@ -664,7 +666,7 @@ class imagebuilderClient(BaseClient):
         """
         Applies a policy to a component.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.put_component_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.put_component_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_component_policy)
         """
 
@@ -674,7 +676,7 @@ class imagebuilderClient(BaseClient):
         """
         Applies a policy to a container image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.put_container_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.put_container_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_container_recipe_policy)
         """
 
@@ -682,7 +684,7 @@ class imagebuilderClient(BaseClient):
         """
         Applies a policy to an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.put_image_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.put_image_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_image_policy)
         """
 
@@ -692,7 +694,7 @@ class imagebuilderClient(BaseClient):
         """
         Applies a policy to an image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.put_image_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.put_image_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_image_recipe_policy)
         """
 
@@ -702,7 +704,7 @@ class imagebuilderClient(BaseClient):
         """
         Manually triggers a pipeline to create an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.start_image_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.start_image_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#start_image_pipeline_execution)
         """
 
@@ -710,7 +712,7 @@ class imagebuilderClient(BaseClient):
         """
         Adds a tag to a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#tag_resource)
         """
 
@@ -718,7 +720,7 @@ class imagebuilderClient(BaseClient):
         """
         Removes a tag from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#untag_resource)
         """
 
@@ -733,7 +735,7 @@ class imagebuilderClient(BaseClient):
         """
         Updates a new distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.update_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.update_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update_distribution_configuration)
         """
 
@@ -755,7 +757,7 @@ class imagebuilderClient(BaseClient):
         """
         Updates an image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.update_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.update_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update_image_pipeline)
         """
 
@@ -778,6 +780,6 @@ class imagebuilderClient(BaseClient):
         """
         Updates a new infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/imagebuilder.html#imagebuilder.Client.update_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/imagebuilder.html#imagebuilder.Client.update_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update_infrastructure_configuration)
         """
